##  Interface
  * Identify interfaces represented by arrows/lines between applications. Name interfaces using the format: [SourceSystem][TargetSystem][DataObjectOrPurpose]_[InterfaceType].
  * Extract all connection lines representing interfaces between systems. Determine provider (start of line) and consumer (end of line/arrow) relationships.
  * Identify interface elements with their associated data objects. Note data flow directions, with the line origin indicating the provider and the arrow end indicating the consumer.
